@@ -9,14 +9,8 @@ use PDK::Device::Concern::Netdisco;
 use Data::Dumper;
 use Data::Printer;
 
-# 测试数据库连接参数
-my $db_params = {
-  host     => '192.168.99.99',
-  port     => 5432,
-  dbname   => 'netdisco',
-  user     => 'netdisco',
-  password => 'Cisc0123'
-};
+my $db_params
+  = {host => '192.168.99.99', port => 5432, dbname => 'netdisco', user => 'netdisco', password => 'Cisc0123'};
 
 my $dbi = PDK::DBI::Pg->new($db_params);
 
@@ -26,5 +20,5 @@ FROM device
 SQL
 
 my $devices = $dbi->execute($sql)->all;
-my $nd = PDK::Device::Concern::Netdisco->new();
-say Dumper $nd->exploreTopologyJob($devices);
\ No newline at end of file
+my $nd      = PDK::Device::Concern::Netdisco->new();
+say Dumper $nd->exploreTopologyJob($devices);
